#!/bin/bash

# This script configures things related to DS9490R adapter, OWFS (one wire filesystem) etc. 
# Argo Ellisson 2014, BashPi.org, usage licence: GNU General Public License (GPL) Version 3
# version 1.1

if [ "$(id -u)" -ne "0" ] ; then
    echo "This script must be executed with root privileges."
    exit 1
fi

# change curent directory to script location
cd $(dirname $0)

# include functions
. ./files/functions.sh

# user homedir backup location
HOMEBACKUP="./files/wire_homedir"
# user/group name - if you change it, check all scripts!
USER="wire"
# udev file name
UDEV="99-wire.rules"
# 1wire filesystem mountpoint
MOUNT="/wire"


usage() {
   echo "THIS script may screw up some existing configuration in your system, please check the script if you care"
   echo "f.e. it will overwrite scripts in ${USER} homedir if they already exist"
   echo "to avoid accidental running please use following to apply configuration:"
   echo "USAGE: configure.sh configure"
   echo "must be run as root user either directly or using sudo"
   cd - > /dev/null
   exit 1
}

case "$1" in
        configure)  

        echo "seting up user"
        add_systemuser ${USER}
        USERHOME=`get_homedir ${USER}`
        rsync -av ${HOMEBACKUP}/* ${USERHOME}
        chown ${USER}:${USER} ${USERHOME}/*
        chmod 700 ${USERHOME}
        chmod 700 ${USERHOME}/${USER}*.sh

        echo "seting up mountpoint"
        [ -d ${MOUNT} ] || mkdir ${MOUNT}
        chown ${USER}:${USER} ${MOUNT} 

	echo "installing required packages"
	try_install owfs

        echo "turning off unneeded services owftpd owhttpd owserver"
        update-rc.d -f owftpd disable
        update-rc.d -f owhttpd disable
        update-rc.d -f owserver disable
        service owftpd stop
        service owhttpd stop
        service owserver stop

        echo "backing up and replacing /etc/owfs.conf"
        [[ -f /etc/owfs.conf ]] && cp /etc/owfs.conf /etc/owfs.conf.old
	cp ./files/owfs.conf /etc/

	# set up fuse.conf
	cp ./files/fuse.conf /etc/

	# load fuse module
	modprobe fuse

	# add user wire to fuse group
	usermod -a -G fuse ${USER}

        # udev rules are here instead of separate file as this way its easier to change scripts locations and users
        echo "seting up udev rules for ds1490f adapter"

	echo "# rule for ds1490f." > /etc/udev/rules.d/${UDEV}
	echo "# Bus 001 Device 006: ID 04fa:2490 Dallas Semiconductor DS1490F 2-in-1 Fob, 1-Wire adapter" >> /etc/udev/rules.d/${UDEV}
        echo "ATTRS{idVendor}==\"04fa\", ATTRS{idProduct}==\"2490\", OWNER=\"${USER}\", GROUP=\"${USER}\", MODE=\"0660\", SYMLINK+=\"ds1490f\", RUN+=\"/bin/su - ${USER} -c ${USERHOME}/wire_monitor.sh &\"" >> /etc/udev/rules.d/${UDEV}

        udevadm control --reload-rules

        # importing crontab
        echo "seting up crontab"
        crontab -u ${USER} ./files/${USER}_crontab

        # copy sudo rules
        echo "seting up sudo rules"
        cp ./files/${USER}_sudoers /etc/sudoers.d/
	chmod 440 /etc/sudoers.d/${USER}_sudoers


        echo "configured! Please reboot to make sure udev rules and automatic startup work correctly."

        ;;
        *) echo "incorrect usage"
        usage
        ;;
esac

cd - > /dev/null

exit 0
